==> tasker-akka-2016.1.1-sources.jar: com/xebialabs/deployit/engine/tasker/TaskSpecification.java <==
package com.xebialabs.deployit.engine.tasker;

import com.google.common.base.Preconditions;
import com.xebialabs.deployit.engine.api.execution.TaskPackageDependency;
import com.xebialabs.deployit.engine.spi.execution.ExecutionStateListener;
import com.xebialabs.deployit.repository.WorkDir;
import org.springframework.security.core.Authentication;

import java.io.Serializable;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import static com.google.common.collect.Lists.newArrayList;
import static com.google.common.collect.Maps.newHashMap;

public class TaskSpecification implements Serializable {
    private final String description;
    private final Authentication owner;
    private final PhaseContainer block;
    private final Map<String, String> metadata = newHashMap();
    private List<ExecutionStateListener> listeners = newArrayList();
    private final WorkDir workDir;
    private final String id;
    private TaskInspectionContext inspectionContext;
    private boolean recoverable;
    private boolean archiveable;
    private boolean nonInteractive;
    private List<TaskPackageDependency> packageDependencies = newArrayList();

    public TaskSpecification(String description, Authentication owner, WorkDir workDir, PhaseContainer block) {
        this(description, owner, workDir, block, null);
    }

    public TaskSpecification(String id, String description, Authentication owner, WorkDir workDir, PhaseContainer block) {
        this(id, description, owner, workDir, block, null, true, true, false);
    }

    public TaskSpecification(String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext) {
        this(description, owner, workDir, block, inspectionContext, true);
    }

    public TaskSpecification(String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext, boolean recoverable) {
        this(description, owner, workDir, block, inspectionContext, recoverable, true);
    }

    public TaskSpecification(String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext, boolean recoverable, boolean archiveable) {
        this(description, owner, workDir, block, inspectionContext, recoverable, archiveable, false);
    }

    public TaskSpecification(String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext, boolean recoverable, boolean archiveable, boolean nonInteractive) {
        this(UUID.randomUUID().toString(), description, owner, workDir, block, inspectionContext, recoverable, archiveable, nonInteractive);
    }

    public TaskSpecification(String id, String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext, boolean recoverable, boolean archiveable) {
        this(id, description, owner, workDir, block, inspectionContext, recoverable, archiveable, false);
    }

    public TaskSpecification(String id, String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext, boolean recoverable, boolean archiveable, boolean nonInteractive) {
        Preconditions.checkNotNull(workDir, "WorkDir cannot be null");
        this.id = id;
        this.description = description;
        this.owner = owner;
        this.block = block;
        this.inspectionContext = inspectionContext;
        this.workDir = workDir;
        this.recoverable = recoverable;
        this.archiveable = archiveable;
        this.nonInteractive = nonInteractive;
    }

    public String getId() {
        return id;
    }

    public String getDescription() {
        return description;
    }

    // Ugly casting ;-)
    @SuppressWarnings("unchecked")
    public List<TaskStep> getSteps() {
        return (List<TaskStep>) ((List) block.getStepList());
    }

    public PhaseContainer getBlock() {
        return block;
    }

    public Authentication getOwner() {
        return owner;
    }

    public Map<String, String> getMetadata() {
        return metadata;
    }

    public List<ExecutionStateListener> getListeners() {
        return listeners;
    }

    public TaskInspectionContext getInspectionContext() {
        return inspectionContext;
    }

    public WorkDir getWorkDir() {
        return workDir;
    }

    public boolean isRecoverable() {
        return recoverable;
    }

    public boolean isArchiveable() {
        return archiveable;
    }

    public boolean isNonInteractive() {
        return nonInteractive;
    }

    public List<TaskPackageDependency> getPackageDependencies() {
        return packageDependencies;
    }
}

==> tasker-akka-2018.3.3-sources.jar: com/xebialabs/deployit/engine/tasker/TaskSpecification.java <==
package com.xebialabs.deployit.engine.tasker;

import com.xebialabs.deployit.checks.Checks;
import com.xebialabs.deployit.engine.api.execution.TaskPackageDependency;
import com.xebialabs.deployit.engine.spi.execution.ExecutionStateListener;
import com.xebialabs.deployit.repository.WorkDir;
import org.springframework.security.core.Authentication;

import java.io.Serializable;
import java.util.*;


public class TaskSpecification implements Serializable {
    private final String description;
    private final Authentication owner;
    private final PhaseContainer block;
    private final Map<String, String> metadata = new HashMap<>();
    private List<ExecutionStateListener> listeners = new ArrayList<>();
    private final WorkDir workDir;
    private final String id;
    private TaskInspectionContext inspectionContext;
    private boolean recoverable;
    private boolean archiveable;
    private boolean nonInteractive;
    private List<TaskPackageDependency> packageDependencies = new ArrayList<>();

    public TaskSpecification(String description, Authentication owner, WorkDir workDir, PhaseContainer block) {
        this(description, owner, workDir, block, null);
    }

    public TaskSpecification(String id, String description, Authentication owner, WorkDir workDir, PhaseContainer block) {
        this(id, description, owner, workDir, block, null, true, true, false);
    }

    public TaskSpecification(String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext) {
        this(description, owner, workDir, block, inspectionContext, true);
    }

    public TaskSpecification(String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext, boolean recoverable) {
        this(description, owner, workDir, block, inspectionContext, recoverable, true);
    }

    public TaskSpecification(String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext, boolean recoverable, boolean archiveable) {
        this(description, owner, workDir, block, inspectionContext, recoverable, archiveable, false);
    }

    public TaskSpecification(String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext, boolean recoverable, boolean archiveable, boolean nonInteractive) {
        this(UUID.randomUUID().toString(), description, owner, workDir, block, inspectionContext, recoverable, archiveable, nonInteractive);
    }

    public TaskSpecification(String id, String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext, boolean recoverable, boolean archiveable) {
        this(id, description, owner, workDir, block, inspectionContext, recoverable, archiveable, false);
    }

    public TaskSpecification(String id, String description, Authentication owner, WorkDir workDir, PhaseContainer block, TaskInspectionContext inspectionContext, boolean recoverable, boolean archiveable, boolean nonInteractive) {
        Checks.checkNotNull(workDir, "WorkDir cannot be null");
        this.id = id;
        this.description = description;
        this.owner = owner;
        this.block = block;
        this.inspectionContext = inspectionContext;
        this.workDir = workDir;
        this.recoverable = recoverable;
        this.archiveable = archiveable;
        this.nonInteractive = nonInteractive;
    }

    public String getId() {
        return id;
    }

    public String getDescription() {
        return description;
    }

    // Ugly casting ;-)
    @SuppressWarnings("unchecked")
    public List<TaskStep> getSteps() {
        return (List<TaskStep>) ((List) block.getStepList());
    }

    public PhaseContainer getBlock() {
        return block;
    }

    public Authentication getOwner() {
        return owner;
    }

    public Map<String, String> getMetadata() {
        return metadata;
    }

    public List<ExecutionStateListener> getListeners() {
        return listeners;
    }

    public TaskInspectionContext getInspectionContext() {
        return inspectionContext;
    }

    public WorkDir getWorkDir() {
        return workDir;
    }

    public boolean isRecoverable() {
        return recoverable;
    }

    public boolean isArchiveable() {
        return archiveable;
    }

    public boolean isNonInteractive() {
        return nonInteractive;
    }

    public List<TaskPackageDependency> getPackageDependencies() {
        return packageDependencies;
    }
}
